@@ -1,14 +1,22 @@
 # -*- coding: utf-8 -*-
+from warnings import warn
+
 import numpy as np
 import pandas as pd
+import scipy.linalg
 
+# from ..ecg import ecg_rsp # TODO: why is ecg_rsp imported as a module, not a function?
+from ..ecg.ecg_rsp import ecg_rsp
+from ..misc import NeuroKitWarning
 from ..rsp import rsp_process
-from ..signal import signal_filter, signal_interpolate, signal_rate, signal_resample
+from ..signal import (signal_filter, signal_interpolate, signal_rate,
+                      signal_resample, signal_timefrequency)
 from ..signal.signal_formatpeaks import _signal_formatpeaks_sanitize
-from ..ecg import ecg_rsp
+from .hrv_utils import _hrv_get_rri
 
 
-def hrv_rsa(ecg_signals, rsp_signals=None, rpeaks=None, sampling_rate=1000, continuous=False):
+def hrv_rsa(ecg_signals, rsp_signals=None, rpeaks=None, sampling_rate=1000, continuous=False,
+            window=None, window_number=None):
     """Respiratory Sinus Arrhythmia (RSA)
 
     Respiratory sinus arrhythmia (RSA), also referred to as 'cardiac coherence' or 'physiological
@@ -59,6 +67,12 @@ def hrv_rsa(ecg_signals, rsp_signals=None, rpeaks=None, sampling_rate=1000, cont
         If False, will return RSA properties computed from the data (one value per index).
         If True, will return continuous estimations of RSA of the same length as the signal.
         See below for more details.
+    window : int
+        For calculating RSA second by second. Length of each segment in seconds. If None (default),
+        window will be set at 32 seconds.
+    window_number : int
+        Between 2 and 8. For caculating RSA second by second. Number of windows to be calculated in
+        Peak Matched Multiple Window. If None (default), window_number will be set at 8.
 
     Returns
     ----------
@@ -97,18 +111,21 @@ def hrv_rsa(ecg_signals, rsp_signals=None, rpeaks=None, sampling_rate=1000, cont
      'RSA_P2T_Mean_log': ...,
      'RSA_P2T_SD': ...,
      'RSA_P2T_NoRSA': ...,
-     'RSA_PorgesBohrer': ...}
+     'RSA_PorgesBohrer': ...,
+     'RSA_Gates_Mean': ...,
+     'RSA_Gates_Mean_log': ...,
+     'RSA_Gates_SD': ...}
     >>>
     >>> # Get RSA as a continuous signal
     >>> rsa = nk.hrv_rsa(ecg_signals, rsp_signals, info, sampling_rate=100, continuous=True)
     >>> rsa #doctest: +ELLIPSIS
-            RSA_P2T
-    0      0.09
-    1      0.09
-    2      0.09
-    ...    ...
+            RSA_P2T  RSA_Gates
+    0         ...         ...
+    1         ...         ...
+    2         ...         ...
+    ...       ...         ...
 
-    [15000 rows x 1 columns]
+    [15000 rows x 2 columns]
     >>> nk.signal_plot([ecg_signals["ECG_Rate"], rsp_signals["RSP_Rate"], rsa], standardize=True)
 
     References
@@ -136,7 +153,10 @@ def hrv_rsa(ecg_signals, rsp_signals=None, rpeaks=None, sampling_rate=1000, cont
     if len(rsp_peaks) - len(rsp_onsets) == 0:
         rsp_peaks = rsp_peaks[:-1]
     if len(rsp_peaks) - len(rsp_onsets) != -1:
-        print("NeuroKit error: ecg_rsp(): Couldn't find rsp cycles onsets and centers. Check your RSP signal.")
+        warn(
+            "Couldn't find rsp cycles onsets and centers. Check your RSP signal.",
+            category=NeuroKitWarning
+        )
 
     # Methods ------------------------
 
@@ -147,12 +167,34 @@ def hrv_rsa(ecg_signals, rsp_signals=None, rpeaks=None, sampling_rate=1000, cont
     # Porges-Bohrer
     rsa_pb = _hrv_rsa_pb(ecg_period, sampling_rate, continuous=continuous)
 
+    # RSAsecondbysecond
+    if window is None:
+        window = 32  # 32 seconds
+    input_duration = rpeaks[-1] / sampling_rate
+    if input_duration >= window:
+        rsa_gates = _hrv_rsa_gates(ecg_signals, rpeaks, sampling_rate=sampling_rate,
+                                   window=window, window_number=window_number, continuous=continuous)
+    else:
+        warn(
+                "The duration of recording is shorter than the duration of the window (%s seconds)."
+                " Returning RSA by Gates method as Nan."
+                " Consider using a longer recording." % (window),
+                category=NeuroKitWarning
+            )
+        if continuous is False:
+            rsa_gates = np.nan
+        else:
+            rsa_gates = np.full(len(rsa_p2t), np.nan)
+
+
     if continuous is False:
         rsa = {}  # Initialize empty dict
         rsa.update(rsa_p2t)
         rsa.update(rsa_pb)
+        rsa.update(rsa_gates)
     else:
-        rsa = pd.DataFrame({"RSA_P2T": rsa_p2t})
+        rsa = pd.DataFrame({"RSA_P2T": rsa_p2t,
+                            "RSA_Gates": rsa_gates})
 
     return rsa
 
@@ -292,6 +334,121 @@ def _hrv_rsa_pb(ecg_period, sampling_rate, continuous=False):
 #    # Not sure what to do next, sent an email to Servant.
 #    pass
 
+# =============================================================================
+# Second-by-second RSA
+# =============================================================================
+
+def _hrv_rsa_gates(ecg_signals, rpeaks, sampling_rate=1000, window=None, window_number=None,
+                   continuous=False):
+
+    # Boundaries of rsa freq
+    min_frequency = 0.12
+    max_frequency = 0.40
+    # Retrived IBI and interpolate it
+    rri, sampling_rate = _hrv_get_rri(rpeaks, sampling_rate=sampling_rate, interpolate=True)
+
+    # Re-sample at 4 Hz
+    desired_sampling_rate = 4
+    rri = signal_resample(rri, sampling_rate=sampling_rate,
+                          desired_sampling_rate=desired_sampling_rate)
+
+    # Sanitize parameters
+    overlap = int((window - 1) * desired_sampling_rate)
+    nperseg = window * desired_sampling_rate
+    if window_number is None:
+        window_number = 8
+
+    # Get multipeak window
+    multipeak, weight = _get_multipeak_window(nperseg, window_number)
+
+    for i in range(4):
+        _, time, psd = signal_timefrequency(rri, sampling_rate=desired_sampling_rate,
+                                            min_frequency=min_frequency,
+                                            max_frequency=max_frequency, method="stft",
+                                            window=window, window_type=multipeak[:, i],
+                                            overlap=overlap, show=False)
+        if i == 0:
+            rsa = np.zeros_like(psd)
+        rsa = psd * weight[i] + rsa  # add weights
+    meanRSA = np.log(2 * sum(rsa) / nperseg)
+
+    # Sanitize output
+    if continuous is False:
+        rsa = {"RSA_Gates_Mean": np.nanmean(meanRSA)}
+        rsa["RSA_Gates_Mean_log"] = np.log(rsa["RSA_Gates_Mean"])  # pylint: disable=E1111
+        rsa["RSA_Gates_SD"] = np.nanstd(meanRSA, ddof=1)
+    else:
+        # For window=32, meanRSA is RSA from 16th second to xth second where x=recording
+        # duration-16secs
+        # Padding the missing first and list window/2 segments
+        pad_length = window / 2
+        time_start = np.arange(0, pad_length)
+        time_end = np.arange(time[-1], time[-1] + pad_length)[1:]
+        time = np.concatenate((time_start, time, time_end))
+
+        rsa_start = np.full(len(time_start), meanRSA[0])
+        rsa_end = np.full(len(time_end), meanRSA[-1])
+        meanRSA = np.concatenate((rsa_start, meanRSA, rsa_end))
+
+        # Convert to samples
+        time = np.multiply(time, sampling_rate)
+
+        rsa = signal_interpolate(time.astype(int), meanRSA, x_new=len(ecg_signals),
+                                 method="monotone_cubic")
+    return rsa
+
+
+def _get_multipeak_window(nperseg, window_number=8):
+    """Get Peak Matched Multiple Window
+    References
+    ----------
+    Hansson, M., & Salomonsson, G. (1997). A multiple window method for estimation of peaked spectra.
+    IEEE Transactions on Signal Processing, 45(3), 778-781.
+    """
+    K1 = 20  # Peak in dB
+    K2 = 30  # Penalty value in dB
+
+    B = (window_number + 2) / nperseg  # Resolution in spectrum
+
+    loge = np.log10(np.exp(1))
+    C = 2 * K1 / 10 / B / loge
+    length = np.arange(1, nperseg).conj().transpose()
+    r0 = 2 / C * (1 - np.exp(-C * B / 2))
+    r_num = (2 * C - np.exp(-C * B / 2) * (2 * C * np.cos(np.pi * B * length) - 4 * np.pi * length *
+                                           np.sin(np.pi * B * length)))
+
+    r_den = (C**2 + (2 * np.pi * length)**2)
+    r = np.divide(r_num, r_den)
+
+    rpeak = np.append(r0, r)  # Covariance function peaked spectrum
+
+    r = 2 * np.sin(np.pi * B * length) / (2 * np.pi * length)
+    rbox = np.append(B, r)
+
+    rpen = 10**(K2 / 10) * np.append(1, np.zeros((nperseg - 1, 1))) - (10**(K2 / 10) - 1) * rbox  # Covariance function penalty function
+
+    Ry = scipy.linalg.toeplitz(rpeak)
+    Rx = scipy.linalg.toeplitz(rpen)
+    RR = scipy.linalg.cholesky(Rx)
+    C = scipy.linalg.inv(RR.conj().transpose()).dot(Ry).dot(scipy.linalg.inv(RR))
+    _, Q = scipy.linalg.schur(C)
+    F = scipy.linalg.inv(RR).dot(Q)
+    RD = F.conj().transpose().dot(Ry).dot(F)
+    RD = np.diag(RD)
+    RDN = np.sort(RD)
+    h = np.argsort(RD)
+
+    FN = np.zeros((nperseg, nperseg))
+    for i in range(len(RD)):
+        FN[:, i] = F[: , h[i]] / np.sqrt(F[: , h[i]].conj().transpose().dot(F[: , h[i]]))
+
+    RDN = RDN[len(RD) - 1: 0: -1]
+    FN = FN[: , len(RD) - 1: 0: -1]
+
+    weight = RDN[: window_number] / np.sum(RDN[: window_number])
+    multipeak = FN[: , 0: window_number]
+
+    return multipeak, weight
 
 # =============================================================================
 # Internals
@@ -332,18 +489,19 @@ def _hrv_rsa_formatinput(ecg_signals, rsp_signals, rpeaks=None, sampling_rate=10
                 ecg_period = signal_rate(rpeaks, sampling_rate=sampling_rate, desired_length=len(ecg_signals))
             else:
                 raise ValueError(
-                    "NeuroKit error: _hrv_rsa_formatinput():" "Wrong input, we couldn't extract" "heart rate signal."
+                    "NeuroKit error: _hrv_rsa_formatinput():"
+                    "Wrong input, we couldn't extract" "heart rate signal."
                 )
     if rsp_signals is None:
         rsp_cols = [col for col in ecg_signals.columns if "RSP_Phase" in col]
         if len(rsp_cols) != 2:
             edr = ecg_rsp(ecg_period, sampling_rate=sampling_rate)
             rsp_signals, _ = rsp_process(edr, sampling_rate)
-            print(
-                "NeuroKit warning: _hrv_rsa_formatinput():"
+            warn(
                 "RSP signal not found. For this time, we will derive RSP"
-                " signal from ECG using ecg_rsp(). But the results are "
-                "definitely not reliable, so please provide a real RSP signal."
+                " signal from ECG using ecg_rsp(). But the results are"
+                " definitely not reliable, so please provide a real RSP signal.",
+                category=NeuroKitWarning
             )
     elif isinstance(rsp_signals, tuple):
         rsp_signals = rsp_signals[0]
@@ -353,17 +511,19 @@ def _hrv_rsa_formatinput(ecg_signals, rsp_signals, rpeaks=None, sampling_rate=10
         if len(rsp_cols) != 2:
             edr = ecg_rsp(ecg_period, sampling_rate=sampling_rate)
             rsp_signals, _ = rsp_process(edr, sampling_rate)
-            print(
-                "NeuroKit warning: _hrv_rsa_formatinput():"
-                "RSP signal not found. RSP signal is derived from ECG using"
-                "ecg_rsp(). Please provide RSP signal."
+            warn(
+                "RSP signal not found. RSP signal is derived from ECG using ecg_rsp()."
+                " Please provide RSP signal.",
+                category=NeuroKitWarning
             )
 
     if rpeaks is None:
         try:
             rpeaks = _signal_formatpeaks_sanitize(ecg_signals)
         except NameError:
-            raise ValueError("NeuroKit error: _hrv_rsa_formatinput(): Wrong input, we couldn't extract rpeaks indices.")
+            raise ValueError(
+                "NeuroKit error: _hrv_rsa_formatinput(): "
+                "Wrong input, we couldn't extract rpeaks indices.")
     else:
         rpeaks = _signal_formatpeaks_sanitize(rpeaks)
 
