@@ -18,11 +18,13 @@ from .signal_plot import signal_plot
 from .signal_power import signal_power
 from .signal_psd import signal_psd
 from .signal_rate import signal_rate
+from .signal_recompose import signal_recompose
 from .signal_resample import signal_resample
 from .signal_simulate import signal_simulate
 from .signal_smooth import signal_smooth
 from .signal_synchrony import signal_synchrony
 from .signal_zerocrossings import signal_zerocrossings
+from .signal_timefrequency import signal_timefrequency
 
 
 __all__ = [
@@ -49,4 +51,6 @@ __all__ = [
     "signal_autocor",
     "signal_changepoints",
     "signal_decompose",
+    "signal_recompose",
+    "signal_timefrequency"
 ]
